@@ -17,7 +17,7 @@ typedef Eo Evas_VG;
 /**
  * @brief Get the root node of the evas_object_vg.
  *
- * Note: To manually create the shape object and show in the Vg object canvas
+ * @note To manually create the shape object and show in the Vg object canvas
  * you must create the hirarchy and set the parent as root node.
  *
  * @return Root node of the VG canvas.
@@ -26,6 +26,6 @@ typedef Eo Evas_VG;
  *
  * @ingroup Evas_VG
  */
-EAPI Efl_VG *evas_object_vg_root_node_get(const Evas_VG *obj);
+EAPI Eo_Base *evas_object_vg_root_node_get(const Evas_VG *obj);
 
 #endif
